const ipRateLimitStore = new Map();

// Clean up old entries every 5 minutes
setInterval(() => {
	const now = Date.now();
	for (const [key, value] of ipRateLimitStore.entries()) {
		if (now - value.timestamp > 60000) {
			// 1 minute
			ipRateLimitStore.delete(key);
		}
	}
}, 5 * 60 * 1000);

const rateLimiter = (req, res, next) => {
	const formUuid = req.params.formUuid;
	const ip = req.ip;
	const key = `${formUuid}_${ip}`;
	const now = Date.now();
	const windowMs = 60000; // 1 minute
	const maxRequests = 5; // 5 requests per minute

	const current = ipRateLimitStore.get(key) || { count: 0, timestamp: now };

	// Reset if window has passed
	if (now - current.timestamp > windowMs) {
		current.count = 0;
		current.timestamp = now;
	}

	// Check if limit exceeded
	if (current.count >= maxRequests) {
		return res.status(429).json({
			error: "Too many requests. Please try again later.",
		});
	}

	// Increment counter
	current.count++;
	ipRateLimitStore.set(key, current);

	next();
};

export default rateLimiter;
